# HepsiPay PHP Payment Gateway SDK

## Kurulum

```
sdk/HepsiPayGateway.php dosyasını projenize dahil etmeniz yeterlidir.
```
```php
use Alttantire\HepsiPaySDK\HepsiPayGateway;

include "../sdk/HepsiPayGateway.php";

$endpoint = "https://merchantpfpayment-gateway-qa.hepsipay.com";
$merchantNo = "10019";
$terminalNo = "1019";
$storeKey = "hza6J/bF7c4adBNWbr9gVmxwsqgXYd3VwatyX6lT/kU=";

$HepsiPayGateway = new HepsiPayGateway($endpoint, $merchantNo, $terminalNo, $storeKey);
```

## Kullanım
API çağrıları için aşağıdaki metodları kullanabilirsiniz.

### Hosted Iframe İşlem Başlatma
Merchant checkout ekranın içine render olacak şekilde stiller uygulanır

```php
<?php

use Alttantire\HepsiPaySDK\HepsiPayGateway;

include "sdk/HepsiPayGateway.php";

$endpoint = "https://merchantpfpayment-gateway-qa.hepsipay.com";
$merchantNo = "XXXXXX";
$terminalNo = "YYYYYY";
$storeKey = "ZZZZZZ";

$HepsiPayGateway = new HepsiPayGateway($endpoint, $merchantNo, $terminalNo, $storeKey);

$HepsiPayGateway->set_amount(1000);
$HepsiPayGateway->set_account_key("905998868296");
$HepsiPayGateway->set_merchant_callback_url("http://hepsipaysdk.entegrasyon.alttantire.local/examples/payment_result.php");
$HepsiPayGateway->set_merchant_order_number("1234-56797");
$HepsiPayGateway->set_is_guest_user(false);
$HepsiPayGateway->set_force_3ds(false);
$HepsiPayGateway->set_allowed_installments([1, 2, 3]);
$HepsiPayGateway->set_bank_order_id("ABC-123-4567");
$HepsiPayGateway->set_external_id("EXT-ID-123-4567");
$HepsiPayGateway->set_pos_alias("");
$HepsiPayGateway->set_frame_type(1);
$HepsiPayGateway->set_basket_item([
    "Product" => "Çikolata",
    "Price" => 500,
    "SubMerchantMemberId" => null,
    "SubMerchantMemberPrice" => null,
    "CategoryId" => "3",
    "ExternalId" => "10"
]);

try {

    // Check Availability
    $frame_check_availability_response = $HepsiPayGateway->check_availability();

    if ($frame_check_availability_response->Success === true) {
        // Frame Init
        $frame_init_response = $HepsiPayGateway->frame_init();

        if ($frame_init_response) {

            if ($frame_init_response->Success === true) {
                $token = $frame_init_response->Token;
                $frame_url = $frame_init_response->FrameUrl;
            } else {
                echo $frame_init_response->Message;
            }
        }
    }

} catch (\Alttantire\HepsiPaySDK\HepsiPaySDKException $e) {
    echo $e->getMessage();
}
```
```html
<iframe src="<?php echo $frame_url ?>"></iframe>
```

### Common Payment Page İşlem Başlatma

Redirected (Common Payment Page) - Merchant checkout ekranında render olmaz harici sayfada ödeme alınır.

```php

use Alttantire\HepsiPaySDK\HepsiPayGateway;

include "sdk/HepsiPayGateway.php";

$endpoint = "https://merchantpfpayment-gateway-qa.hepsipay.com";
$merchantNo = "XXXX";
$terminalNo = "YYYY";
$storeKey = "ZZZZZ";

$HepsiPayGateway = new HepsiPayGateway($endpoint, $merchantNo, $terminalNo, $storeKey);

$HepsiPayGateway->set_amount(1000);
$HepsiPayGateway->set_account_key("905998868296");
$HepsiPayGateway->set_merchant_callback_url("http://hepsipaysdk.entegrasyon.alttantire.local/examples/payment_result.php");
$HepsiPayGateway->set_merchant_order_number("1234-56797");
$HepsiPayGateway->set_is_guest_user(false);
$HepsiPayGateway->set_force_3ds(false);
$HepsiPayGateway->set_allowed_installments([1, 2, 3]);
$HepsiPayGateway->set_bank_order_id("ABC-123-4567");
$HepsiPayGateway->set_external_id("EXT-ID-123-4567");
$HepsiPayGateway->set_pos_alias("");
$HepsiPayGateway->set_frame_type(2);
$HepsiPayGateway->set_checkout_merchant_url("http://hepsipaysdk.entegrasyon.alttantire.local/examples/payment_result.php");

$HepsiPayGateway->set_basket_item([
    "Product" => "Çikolata",
    "Price" => 500,
    "SubMerchantMemberId" => null,
    "SubMerchantMemberPrice" => null,
    "CategoryId" => "3",
    "ExternalId" => "10"
]);

try {

    // Check Availability
    $frame_check_availability_response = $HepsiPayGateway->check_availability();

    if ($frame_check_availability_response->Success === true) {

        // Frame Init
        $frame_init_response = $HepsiPayGateway->frame_init();

        if ($frame_init_response) {

            if ($frame_init_response->Success === true) {

                $token = $frame_init_response->Token;
                $frame_url = $frame_init_response->FrameUrl;

            } else {
                echo $frame_init_response->Message;
            }
        }
    }

} catch (\Alttantire\HepsiPaySDK\HepsiPaySDKException $e) {
    echo $e->getMessage();
}
```
```html
<iframe src="<?php echo $frame_url ?>"></iframe>
```

### Ödeme Sorgulama

```php
<?php

use Alttantire\HepsiPaySDK\HepsiPayGateway;

include "sdk/HepsiPayGateway.php";

$endpoint = "https://merchantpfpayment-gateway-qa.hepsipay.com";
$merchantNo = "XXXXX";
$terminalNo = "YYYYY";
$storeKey = "ZZZZZ";

$HepsiPayGateway = new HepsiPayGateway($endpoint, $merchantNo, $terminalNo, $storeKey);

$token = "ABCDEFGH";
$payment_status = $HepsiPayGateway->payment_status($token);

print_r($payment_status);

```

### İade (Payment Id ile)

```php
<?php
use Alttantire\HepsiPaySDK\HepsiPayGateway;

include "sdk/HepsiPayGateway.php";

$endpoint = "https://merchantpfpayment-gateway-qa.hepsipay.com";
$merchantNo = "XXXXX";
$terminalNo = "YYYYY";
$storeKey = "ZZZZZ";

$HepsiPayGateway = new HepsiPayGateway($endpoint, $merchantNo, $terminalNo, $storeKey);

$HepsiPayGateway->set_refund_amount(100); // 1 TL
$HepsiPayGateway->set_client_ip("127.0.0.1"); // IP Address
$HepsiPayGateway->set_payment_id("709840"); // PaymentID

try {
    $payment_refund_status = $HepsiPayGateway->payment_refund_with_payment_id();
    print_r($payment_refund_status);
    
} catch (\Alttantire\HepsiPaySDK\HepsiPaySDKException $e) {
    echo $e->getMessage();
}
```

### İade (Reference No ile)

```php
<?php
use Alttantire\HepsiPaySDK\HepsiPayGateway;

include "../sdk/HepsiPayGateway.php";

$endpoint = "https://merchantpfpayment-gateway-qa.hepsipay.com";
$merchantNo = "XXXXX";
$terminalNo = "YYYYY";
$storeKey = "ZZZZZ";

$HepsiPayGateway = new HepsiPayGateway($endpoint, $merchantNo, $terminalNo, $storeKey);

$HepsiPayGateway->set_refund_amount(100); // 1 TL
$HepsiPayGateway->set_client_ip("127.0.0.1"); // IP Adres
$HepsiPayGateway->set_reference_no("e828cf3b-72ae-4cb0-b459-88766396e2a6"); //

try {
    $payment_refund_status = $HepsiPayGateway->payment_refund_with_reference_no();
    print_r($payment_refund_status);
    
} catch (\Alttantire\HepsiPaySDK\HepsiPaySDKException $e) {
    echo $e->getMessage();
}
```